using Confluent.Kafka;

namespace ConsumerWorker;

public class ConsumerA : BackgroundService
{
    readonly IConsumer<string, string> consumer;

    public ConsumerA()
    {
        string topic = "testtopic";
        Console.WriteLine("in ConsumerA constructor");

        ConsumerConfig _consumerConfig = new ConsumerConfig
        {
            AutoOffsetReset = AutoOffsetReset.Latest,
            BootstrapServers = "127.0.0.1:64886",
            GroupId = Guid.NewGuid().ToString(),
        };
        consumer = new ConsumerBuilder<string, string>(_consumerConfig).Build();
        consumer.Subscribe(topic);
    }

    protected override async Task ExecuteAsync(CancellationToken stoppingToken)
    {
        Console.WriteLine("In ConsumerA ExecuteAsync");
        await Task.Factory.StartNew(() => ConsumerLoop(stoppingToken), TaskCreationOptions.LongRunning);
    }

    private void ConsumerLoop(CancellationToken stoppingToken)
    {
        Console.WriteLine("ConsumerA in ConsumerLoop");

        while (!stoppingToken.IsCancellationRequested)
        {
            var consumeResult = consumer.Consume(stoppingToken);

            Console.WriteLine($"ConsumerA Received: '{consumeResult.Message.Value}'.");
        }
    }
}
