using Confluent.Kafka;

namespace ConsumerWorker;

public class ConsumerB : BackgroundService
{

    readonly IConsumer<string, string> consumer;

    public ConsumerB()
    {
        Console.WriteLine("In ConsumerB constructor");

        ConsumerConfig _consumerConfig = new ConsumerConfig
        {
            AutoOffsetReset = AutoOffsetReset.Latest,
            BootstrapServers = "127.0.0.1:64886",
            GroupId = Guid.NewGuid().ToString(),
        };
        consumer = new ConsumerBuilder<string, string>(_consumerConfig).Build();
        consumer.Subscribe("testtopic");
    }
    protected override async Task ExecuteAsync(CancellationToken stoppingToken)
    {
        Console.WriteLine("In ConsumerB ExecuteAsync");
        await Task.Factory.StartNew(() => ConsumerLoop(stoppingToken), TaskCreationOptions.LongRunning);
    }

    private void ConsumerLoop(CancellationToken stoppingToken)
    {
        Console.WriteLine("ConsumerB in ConsumerLoop");

        while (!stoppingToken.IsCancellationRequested)
        {
            var consumeResult = consumer.Consume(stoppingToken);

            Console.WriteLine($"\tConsumerB Received: '{consumeResult.Message.Value}'.");
        }
    }
}
